@@ -143,7 +143,7 @@ class BaseRouteHandler(Generic[T]):
             self._resolved_guards = []
             for layer in self.ownership_layers:
                 self._resolved_guards.extend(layer.guards or [])
-            self._resolved_guards = cast("List[Guard]", [AsyncCallable(guard) for guard in self._resolved_guards])
+            self._resolved_guards = cast("List[Guard]", [AsyncCallable(guard) for guard in self._resolved_guards])  # type: ignore[arg-type]
         return cast("List[Guard]", self._resolved_guards)
 
     def resolve_dependencies(self) -> Dict[str, Provide]:
