@@ -150,6 +150,87 @@ class KwargsModel:
             or expected_reserved_kwargs
         )
 
+    @classmethod
+    def _get_param_definitions(
+        cls,
+        path_parameters: Set[str],
+        layered_parameters: Dict[str, ModelField],
+        dependencies: Dict[str, Provide],
+        signature_model_fields: Dict[str, ModelField],
+    ) -> Tuple[Set[ParameterDefinition], set]:
+        """This function gets parameter_definitions for the construction of
+        KwargsModel instance.
+
+        Args:
+            path_parameters: Any expected path parameters.
+            layered_parameters: A string keyed dictionary of layered parameters.
+            dependencies: A string keyed dictionary mapping dependency providers.
+            signature_model_fields: __fields__ definition from SignatureModel.
+
+        Returns:
+            A Tuple of sets
+        """
+        expected_dependencies = {
+            cls._create_dependency_graph(key=key, dependencies=dependencies)
+            for key in dependencies
+            if key in signature_model_fields
+        }
+        ignored_keys = {*RESERVED_KWARGS, *(dependency.key for dependency in expected_dependencies)}
+
+        param_definitions = {
+            *(
+                cls._create_parameter_definition(
+                    allow_none=model_field.allow_none,
+                    field_name=field_name,
+                    field_info=model_field.field_info,
+                    path_parameters=path_parameters,
+                    is_sequence=model_field.shape in SEQ_SHAPES,
+                )
+                for field_name, model_field in layered_parameters.items()
+                if field_name not in ignored_keys and field_name not in signature_model_fields
+            ),
+            *(
+                cls._create_parameter_definition(
+                    allow_none=model_field.allow_none,
+                    field_name=field_name,
+                    field_info=model_field.field_info,
+                    path_parameters=path_parameters,
+                    is_sequence=model_field.shape in SEQ_SHAPES,
+                )
+                for field_name, model_field in signature_model_fields.items()
+                if field_name not in ignored_keys and field_name not in layered_parameters
+            ),
+        }
+
+        for field_name, model_field in filter(
+            lambda items: items[0] not in ignored_keys and items[0] in layered_parameters,
+            signature_model_fields.items(),
+        ):
+            layer_field_info = layered_parameters[field_name].field_info
+            signature_field_info = model_field.field_info
+
+            field_info = layer_field_info
+            # allow users to manually override Parameter definition using Parameter
+            if signature_field_info.extra.get(EXTRA_KEY_IS_PARAMETER):
+                field_info = signature_field_info
+
+            field_info.default = (
+                signature_field_info.default
+                if signature_field_info.default not in [Undefined, Ellipsis]
+                else layer_field_info.default
+            )
+
+            param_definitions.add(
+                cls._create_parameter_definition(
+                    allow_none=model_field.allow_none,
+                    field_name=field_name,
+                    field_info=field_info,
+                    path_parameters=path_parameters,
+                    is_sequence=model_field.shape in SEQ_SHAPES,
+                )
+            )
+        return param_definitions, expected_dependencies
+
     @classmethod
     def create_for_signature_model(
         cls,
@@ -181,66 +262,10 @@ class KwargsModel:
         expected_reserved_kwargs = {
             field_name for field_name in signature_model.__fields__ if field_name in RESERVED_KWARGS
         }
-        expected_dependencies = {
-            cls._create_dependency_graph(key=key, dependencies=dependencies)
-            for key in dependencies
-            if key in signature_model.__fields__
-        }
 
-        ignored_keys = {*RESERVED_KWARGS, *(dependency.key for dependency in expected_dependencies)}
-
-        param_definitions = {
-            *(
-                cls._create_parameter_definition(
-                    allow_none=model_field.allow_none,
-                    field_name=field_name,
-                    field_info=model_field.field_info,
-                    path_parameters=path_parameters,
-                    is_sequence=model_field.shape in SEQ_SHAPES,
-                )
-                for field_name, model_field in layered_parameters.items()
-                if field_name not in ignored_keys and field_name not in signature_model.__fields__
-            ),
-            *(
-                cls._create_parameter_definition(
-                    allow_none=model_field.allow_none,
-                    field_name=field_name,
-                    field_info=model_field.field_info,
-                    path_parameters=path_parameters,
-                    is_sequence=model_field.shape in SEQ_SHAPES,
-                )
-                for field_name, model_field in signature_model.__fields__.items()
-                if field_name not in ignored_keys and field_name not in layered_parameters
-            ),
-        }
-
-        for field_name, model_field in filter(
-            lambda items: items[0] not in ignored_keys and items[0] in layered_parameters,
-            signature_model.__fields__.items(),
-        ):
-            layer_field_info = layered_parameters[field_name].field_info
-            signature_field_info = model_field.field_info
-
-            field_info = layer_field_info
-            # allow users to manually override Parameter definition using Parameter
-            if signature_field_info.extra.get(EXTRA_KEY_IS_PARAMETER):
-                field_info = signature_field_info
-
-            field_info.default = (
-                signature_field_info.default
-                if signature_field_info.default not in [Undefined, Ellipsis]
-                else layer_field_info.default
-            )
-
-            param_definitions.add(
-                cls._create_parameter_definition(
-                    allow_none=model_field.allow_none,
-                    field_name=field_name,
-                    field_info=field_info,
-                    path_parameters=path_parameters,
-                    is_sequence=model_field.shape in SEQ_SHAPES,
-                )
-            )
+        param_definitions, expected_dependencies = cls._get_param_definitions(
+            path_parameters, layered_parameters, dependencies, signature_model_fields=signature_model.__fields__
+        )
 
         expected_path_parameters = {p for p in param_definitions if p.param_type == ParamType.PATH}
         expected_header_parameters = {p for p in param_definitions if p.param_type == ParamType.HEADER}
