@@ -2,14 +2,17 @@ from starlite.middleware.authentication import (
     AbstractAuthenticationMiddleware,
     AuthenticationResult,
 )
+from starlite.middleware.base import DefineMiddleware, MiddlewareProtocol
 from starlite.middleware.compression import CompressionMiddleware
 from starlite.middleware.csrf import CSRFMiddleware
 from starlite.middleware.exceptions import ExceptionHandlerMiddleware
 
 __all__ = [
-    "ExceptionHandlerMiddleware",
-    "AuthenticationResult",
     "AbstractAuthenticationMiddleware",
-    "CompressionMiddleware",
+    "AuthenticationResult",
     "CSRFMiddleware",
+    "CompressionMiddleware",
+    "DefineMiddleware",
+    "ExceptionHandlerMiddleware",
+    "MiddlewareProtocol",
 ]
