@@ -1,10 +1,10 @@
 import re
-from typing import Sequence
+from typing import Iterable
 
 
 def normalize_path(path: str) -> str:
-    """
-    Normalizes a given path by ensuring it starts with a slash and does not end with a slash
+    """Normalizes a given path by ensuring it starts with a slash and does not
+    end with a slash.
 
     Args:
         path: Path string
@@ -19,8 +19,6 @@ def normalize_path(path: str) -> str:
     return path
 
 
-def join_paths(paths: Sequence[str]) -> str:
-    """
-    Normalizes and joins path fragments
-    """
+def join_paths(paths: Iterable[str]) -> str:
+    """Normalizes and joins path fragments."""
     return normalize_path("/".join(paths))
